<!-------------------------------------------------------------------->
<!--                            WARNING!                            -->
<!-------------------------------------------------------------------->
<!--                                                                -->
<!-- THIS IS AN AUTOGENERATED FILE. DO NOT EDIT THIS FILE DIRECTLY. -->
<!-- but run the following script $ npm run build                   -->
<!--                                                                -->
<!-------------------------------------------------------------------->
<!-------------------------------------------------------------------->

# Kafka Test Helper APIs
## Classes

<dl>
<dt><a href="#KafkaTestHelper">KafkaTestHelper</a></dt>
<dd><p>KafkaTestHelper is the class that helps you interacting with Apache Kafka</p>
</dd>
</dl>

## Functions

<dl>
<dt><a href="#createKafkaTestHelper">createKafkaTestHelper(kafka, topic)</a> ⇒ <code><a href="#KafkaTestHelper">KafkaTestHelper</a></code></dt>
<dd><p>Creates and returns an instance of KafkaTestHelper</p>
</dd>
</dl>

## Typedefs

<dl>
<dt><a href="#ConsumedMessage">ConsumedMessage</a> : <code>Object</code></dt>
<dd></dd>
<dt><a href="#ProducibleMessage">ProducibleMessage</a> : <code>Object</code></dt>
<dd></dd>
</dl>

# Specs
<a name="KafkaTestHelper"></a>

## KafkaTestHelper
KafkaTestHelper is the class that helps you interacting with Apache Kafka

**Kind**: global class  
**See**: You can construct a KafkaTestHelper instancevia [createKafkaTestHelper](#createKafkaTestHelper) method  

* [KafkaTestHelper](#KafkaTestHelper)
    * [.reset()](#KafkaTestHelper+reset)
    * [.ensureTopicExists([timeout])](#KafkaTestHelper+ensureTopicExists)
    * [.ensureTopicDeleted([timeout])](#KafkaTestHelper+ensureTopicDeleted)
    * [.messages()](#KafkaTestHelper+messages) ⇒ [<code>Array.&lt;ConsumedMessage&gt;</code>](#ConsumedMessage)
    * [.publishMessages(messages)](#KafkaTestHelper+publishMessages)

<a name="KafkaTestHelper+reset"></a>

### kafkaTestHelper.reset()
Resets the helper to the current offset

**Kind**: instance method of [<code>KafkaTestHelper</code>](#KafkaTestHelper)  
**Example**  
```js
await helper.reset()
```
<a name="KafkaTestHelper+ensureTopicExists"></a>

### kafkaTestHelper.ensureTopicExists([timeout])
Creates a topic if doesn't exist

**Kind**: instance method of [<code>KafkaTestHelper</code>](#KafkaTestHelper)  

| Param | Type | Default | Description |
| --- | --- | --- | --- |
| [timeout] | <code>number</code> | <code>5000</code> | Timeout in ms |

**Example**  
```js
await helper.ensureTopicExists()
```
<a name="KafkaTestHelper+ensureTopicDeleted"></a>

### kafkaTestHelper.ensureTopicDeleted([timeout])
Deletes a topic if exists

**Kind**: instance method of [<code>KafkaTestHelper</code>](#KafkaTestHelper)  

| Param | Type | Default | Description |
| --- | --- | --- | --- |
| [timeout] | <code>number</code> | <code>5000</code> | Timeout in ms |

**Example**  
```js
await helper.ensureTopicDeleted()
```
<a name="KafkaTestHelper+messages"></a>

### kafkaTestHelper.messages() ⇒ [<code>Array.&lt;ConsumedMessage&gt;</code>](#ConsumedMessage)
Returns a list of messages published to the topic from last helper reset

**Kind**: instance method of [<code>KafkaTestHelper</code>](#KafkaTestHelper)  
**Example**  
```js
const msgs = await helper.messages()
[
 {
    headers: {}
    partition: 0,
    buffer: <Buffer 7b 22 62 61 72 22 3a 34 32 7d>,
    json: { "bar": 42 },
    string: '{"bar":42}',
 },
 ...
]
```
<a name="KafkaTestHelper+publishMessages"></a>

### kafkaTestHelper.publishMessages(messages)
Publishes a list of messages to the topic

**Kind**: instance method of [<code>KafkaTestHelper</code>](#KafkaTestHelper)  

| Param | Type | Description |
| --- | --- | --- |
| messages | [<code>Array.&lt;ProducibleMessage&gt;</code>](#ProducibleMessage) | List of messages to publish |

**Example**  
```js
await helper.publishMessages([
 {
   partition: 0,
   key: 'key1',
   string: "hello world",
 },
...
])
```
**Example**  
```js
await helper.publishMessages([
 {
   partition: 0,
   key: 'key1',
   json: { "foo": "bar" },
 },
...
])
```
**Example**  
```js
await helper.publishMessages([
 {
   partition: 0,
   key: 'key1',
   buffer: Buffer.from('hello world')
 },
...
])
```
<a name="createKafkaTestHelper"></a>

## createKafkaTestHelper(kafka, topic) ⇒ [<code>KafkaTestHelper</code>](#KafkaTestHelper)
Creates and returns an instance of KafkaTestHelper

**Kind**: global function  

| Param | Type | Description |
| --- | --- | --- |
| kafka | <code>Kafka</code> | KafkaJS instance. See [https://kafka.js.org/docs/configuration](https://kafka.js.org/docs/configuration) |
| topic | <code>string</code> | Topic that the helper is going to monitor |

**Example**  
```js
import { createKafkaTestHelper } from 'kafka-test-helper'

test('your test', async () => {
 const kafka = getKafka() // see https://kafka.js.org/docs/configuration
 const topicPrefix = Date.now() //  this avoids cross test interference
 const topicHelper = await createKafkaTestHelper(kafka, topicPrefix + 'test-topic')
 //do your tests here
})
```
<a name="ConsumedMessage"></a>

## ConsumedMessage : <code>Object</code>
**Kind**: global typedef  
**Properties**

| Name | Type | Description |
| --- | --- | --- |
| headers | <code>Object</code> | Object with headers |
| partition | <code>number</code> | Partition number |
| buffer | <code>Buffer</code> | Buffer with message |
| json | <code>Object</code> | Object with message |
| string | <code>string</code> | String with message |

<a name="ProducibleMessage"></a>

## ProducibleMessage : <code>Object</code>
**Kind**: global typedef  
**Properties**

| Name | Type | Description |
| --- | --- | --- |
| partition | <code>number</code> | Partition number |
| key | <code>string</code> | Message key |
| buffer | <code>Buffer</code> | Message value as Buffer |
| json | <code>Object</code> | Message value as object and serialized with JSON.stringify() |
| string | <code>string</code> | Message value as string |

